==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/config/lang/eu/lang.php <==
<?php
/**
 * Basque language file
 *
 * @author Inko Illarramendi <inko.i.a@gmail.com>
 */
$lang['menu']                  = 'Konfigurazio Ezarpenak';
$lang['error']                 = 'Ezarpenak ez dira eguneratu balio oker bat dela eta, mesedez errepasatu aldaketak eta berriz bidali. <br />Balio okerra(k) ertz gorriz inguratuak erakutsiko dira. ';
$lang['updated']               = 'Ezarpenak arrakastaz eguneratuak.';
$lang['nochoice']              = '(ez dago beste aukerarik)';
$lang['locked']                = 'Ezarpenen fitxategia ezin da eguneratu, eta intentzioa hau ez bada, <br />
ziurtatu ezarpen lokalen izena eta baimenak zuzenak direla.';
$lang['_configuration_manager'] = 'Konfigurazio Kudeatzailea';
$lang['_header_dokuwiki']      = 'DokuWiki Ezarpenak';
$lang['_header_plugin']        = 'Plugin Ezarpenak';
$lang['_header_template']      = 'Txantiloi Ezarpenak';
$lang['_header_undefined']     = 'Zehaztu gabeko Ezarpenak';
$lang['_basic']                = 'Oinarrizko Ezarpenak';
$lang['_display']              = 'Aurkezpen Ezarpenak';
$lang['_authentication']       = 'Kautotze Ezarpenak';
$lang['_anti_spam']            = 'Anti-Spam Ezarpenak';
$lang['_editing']              = 'Edizio Ezarpenak';
$lang['_links']                = 'Esteken Ezarpenak';
$lang['_media']                = 'Multimedia Ezarpenak';
$lang['_advanced']             = 'Ezarpen Aurreratuak';
$lang['_network']              = 'Sare Ezarpenak';
$lang['_plugin_sufix']         = 'Plugin Ezarpenak';
$lang['_template_sufix']       = 'Txantiloi Ezarpenak';
$lang['_msg_setting_undefined'] = 'Ezarpen metadaturik ez.';
$lang['_msg_setting_no_class'] = 'Ezarpen klaserik ez.';
$lang['_msg_setting_no_default'] = 'Balio lehenetsirik ez.';
$lang['fmode']                 = 'Fitxategi sortze modua';
$lang['dmode']                 = 'Direktorio sortze modua';
$lang['lang']                  = 'Hizkuntza';
$lang['basedir']               = 'Oinarri direktorioa';
$lang['baseurl']               = 'Oinarri URLa';
$lang['savedir']               = 'Datuak gordetzeko direktorioa';
$lang['start']                 = 'Hasiera orriaren izena';
$lang['title']                 = 'Wiki-aren izenburua';
$lang['template']              = 'Txantiloia';
$lang['license']               = 'Zein lizentziapean argitaratu beharko lirateke edukiak?';
$lang['fullpath']              = 'Orri oinean orrien bide osoa erakutsi';
$lang['recent']                = 'Azken aldaketak';
$lang['breadcrumbs']           = 'Arrasto pauso kopurua';
$lang['youarehere']            = 'Arrasto pauso hierarkikoak';
$lang['typography']            = 'Ordezkapen tipografikoak egin';
$lang['htmlok']                = 'Enbotatutako HTMLa baimendu';
$lang['phpok']                 = 'Enbotatutako PHPa baimendu';
$lang['dformat']               = 'Data formatua (ikusi PHPren <a href="http://www.php.net/strftime">strftime</a> funtzioa)';
$lang['signature']             = 'Sinadura';
$lang['toptoclevel']           = 'Eduki taularen goiko maila';
$lang['tocminheads']           = 'Gutxiengo izenburu kopuru minimoa Edukien Taula-ren sortu dadin.';
$lang['maxtoclevel']           = 'Eduki taularen maila maximoa';
$lang['maxseclevel']           = 'Sekzio edizio mailaren maximoa';
$lang['camelcase']             = 'Estekentzat CamelCase erabili';
$lang['deaccent']              = 'Orri izen garbiak';
$lang['useheading']            = 'Erabili lehen izenburua orri izen moduan';
$lang['refcheck']              = 'Multimedia erreferentzia kontrolatu';
$lang['refshow']               = 'Erakusteko multimedia erreferentzia kopurua';
$lang['allowdebug']            = 'Baimendu debug-a <b>ezgaitu behar ez bada!</b>';
$lang['usewordblock']          = 'Blokeatu spam-a hitz zerrenda batean oinarrituta';
$lang['indexdelay']            = 'Denbora atzerapena indexatu baino lehen (seg)';
$lang['relnofollow']           = 'Erabili rel="nofollow" kanpo esteketan';
$lang['mailguard']             = 'Ezkutatu posta-e helbidea';
$lang['iexssprotect']          = 'Egiaztatu igotako fitxategiak JavaScript edo HTML kode maltzurra detektatzeko';
$lang['showuseras']            = 'Zer azaldu orri bat editatu duen azken erabiltzailea erakusterakoan';
$lang['useacl']                = 'Erabili atzipen kontrol listak';
$lang['autopasswd']            = 'Pasahitzak automatikoki sortu';
$lang['authtype']              = 'Kautotze backend-a';
$lang['passcrypt']             = 'Pasahitz enkriptatze metodoa';
$lang['defaultgroup']          = 'Talde lehenetsia';
$lang['superuser']             = 'Supererabiltzailea - taldea, erabiltzailea edo komaz bereiztutako zerrenda user1,@group1,user2 orri eta funtzio guztietara atzipen osoarekin, AKL-ren ezarpenetan zehaztutakoa kontutan hartu gabe';
$lang['manager']               = 'Kudeatzailea - talde, erabiltzaile edo komaz bereiztutako zerrenda user1,@group1,user2 kudeatze funtzio zehatz batzuetara atzipenarekin';
$lang['profileconfirm']        = 'Profil aldaketak pasahitzaz berretsi';
$lang['disableactions']        = 'DokuWiki ekintzak ezgaitu';
$lang['disableactions_check']  = 'Egiaztatu';
$lang['disableactions_subscription'] = 'Harpidetu/Harpidetza utzi';
$lang['disableactions_nssubscription'] = 'Izen-espaziora Harpidetu/Harpidetza utzi';
$lang['disableactions_wikicode'] = 'Ikusi iturburua/Esportatu Raw';
$lang['disableactions_other']  = 'Beste ekintzak (komaz bereiztuak)';
$lang['sneaky_index']          = 'Lehenespenez, DokuWiki-k izen-espazio guztiak indize bistan erakutsiko ditu. Aukera hau gaituta, erabiltzaieak irakurtzeko baimenik ez dituen izen-espazioak ezkutatuko dira. Honek atzigarriak diren azpi izen-espazioak ezkutatzen ditu. Agian honek indizea erabili ezin ahal izatea eragingo du AKL ezarpen batzuetan.';
$lang['auth_security_timeout'] = 'Kautotze Segurtasun Denbora-Muga (segunduak)';
$lang['securecookie']          = 'HTTPS bidez ezarritako cookie-ak HTTPS bidez bakarrik bidali beharko lituzke nabigatzaileak? Ezgaitu aukera hau bakarrik saio hasierak SSL bidezko segurtasuna badu baina wiki-areb nabigazioa modu ez seguruan egiten bada. ';
$lang['updatecheck']           = 'Konprobatu eguneratze eta segurtasun oharrak? DokuWiki-k honetarako splitbrain.org kontaktatu behar du.';
$lang['userewrite']            = 'Erabili URL politak';
$lang['useslash']              = 'Erabili barra (/) izen-espazio banatzaile moduan URLetan';
$lang['usedraft']              = 'Automatikoki zirriborroa gorde editatze garaian';
$lang['sepchar']               = 'Orri izenaren hitz banatzailea';
$lang['canonical']             = 'Erabili URL erabat kanonikoak';
$lang['autoplural']            = 'Kontrolatu forma pluralak esteketan';
$lang['compression']           = 'Trinkotze metodoa attic fitxategientzat';
$lang['cachetime']             = 'Adin maximoa cachearentzat (seg)';
$lang['locktime']              = 'Adin maximoa lock fitxategientzat (seg)';
$lang['fetchsize']             = 'Kanpo esteketatik fetch.php-k deskargatu dezakeen tamaina maximoa (byteak)';
$lang['notify']                = 'Aldaketen jakinarazpenak posta-e helbide honetara bidali';
$lang['registernotify']        = 'Erregistratu berri diren erabiltzaileei buruzko informazioa post-e helbide honetara bidali';
$lang['mailfrom']              = 'Posta automatikoentzat erabiliko den posta-e helbidea';
$lang['gzip_output']           = 'Gzip Eduki-Kodeketa erabili xhtml-rentzat';
$lang['gdlib']                 = 'GD Lib bertsioa';
$lang['im_convert']            = 'ImageMagick-en aldaketa tresnara bidea';
$lang['jpg_quality']           = 'JPG konprimitze kalitatea (0-100)';
$lang['subscribers']           = 'Gaitu orri harpidetza euskarria';
$lang['compress']              = 'Trinkotu CSS eta javascript irteera';
$lang['hidepages']             = 'Ezkutatu kointzidentziak dituzten orriak (espresio erregularrak)';
$lang['send404']               = 'Bidali "HTTP 404/Ez Da Orria Aurkitu" existitzen ez diren orrientzat';
$lang['sitemap']               = 'Sortu Google gune-mapa (egunak)';
$lang['broken_iua']            = 'Zure sisteman ignore_user_abort (erabiltzailearen bertan behera uztea kontuan ez hartu) funtzioa hautsia al dago? Honek funtzionatzen ez duen bilaketa indize bat eragin dezake. ISS+PHP/CGI hautsiak daude. Ikusi <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> informazio gehiago jasotzeko.';
$lang['xsendfile']             = 'X-Sendfile goiburua erabili web zerbitzariari fitxategi estatikoak bidaltzen uzteko? Zure web zerbitzariak hau ahalbidetuta eduki beharko du.';
$lang['xmlrpc']                = 'Gaitu/ezgaitu XML-RPC interfazea.';
$lang['renderer_xhtml']        = 'Erabiliko den errenderizatzailea wiki irteera (xhtml) nagusiarentzat';
$lang['renderer__core']        = '%s (dokuwiki-ren nukleoa)';
$lang['renderer__plugin']      = '%s (plugina)';
$lang['rememberme']            = 'Baimendu saio hasiera cookie iraunkorrak (gogoratu iezaidazu)';
$lang['rss_type']              = 'XML jario mota';
$lang['rss_linkto']            = 'XML jarioak hona estekatzen du';
$lang['rss_content']           = 'Zer erakutsi XML jarioetan?';
$lang['rss_update']            = 'XML jarioaren eguneratze tartea (seg)';
$lang['recent_days']           = 'Zenbat azken aldaketa gordeko dira (egunak)';
$lang['rss_show_summary']      = 'XML jarioak laburpena erakusten du izenburuan';
$lang['target____wiki']        = 'Barne estekentzat helburu leihoa';
$lang['target____interwiki']   = 'Interwiki estekentzat helburu leihoa';
$lang['target____extern']      = 'Kanpo estekentzat helburu leihoa';
$lang['target____media']       = 'Multimedia estekentzat helburu leihoa';
$lang['target____windows']     = 'Leihoen estekentzat helburu leihoa';
$lang['proxy____host']         = 'Proxy zerbitzari izena';
$lang['proxy____port']         = 'Proxy portua';
$lang['proxy____user']         = 'Proxyaren erabiltzaile izena';
$lang['proxy____pass']         = 'Proxyaren pasahitza ';
$lang['proxy____ssl']          = 'Erabili SSL Proxyra konektatzeko';
$lang['safemodehack']          = 'Gaitu modu segurua hack-a';
$lang['ftp____host']           = 'FTP zerbitzaria modu seguruarentzat';
$lang['ftp____port']           = 'FTP portua modu seguruarentzat';
$lang['ftp____user']           = 'FTP erabiltzailea modu seguruarentzat';
$lang['ftp____pass']           = 'FTP pasahitza modu seguruarentzat';
$lang['ftp____root']           = 'FTP erro direktorioa modu seguruarentzat';
$lang['license_o_']            = 'Bat ere ez hautaturik';
$lang['typography_o_0']        = 'ezer';
$lang['typography_o_1']        = 'Komatxo bikoitzak bakarrik';
$lang['typography_o_2']        = 'Komatxo guztiak (gerta daiteke beti ez funtzionatzea)';
$lang['userewrite_o_0']        = 'ezer';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'DokuWikiren barnekoa';
$lang['deaccent_o_0']          = 'Izalita';
$lang['deaccent_o_1']          = 'azentu-markak kendu';
$lang['deaccent_o_2']          = 'erromanizatu ';
$lang['gdlib_o_0']             = 'GD Lib ez dago eskuragarri';
$lang['gdlib_o_1']             = '1.x bertsioa';
$lang['gdlib_o_2']             = 'Automatikoki detektatu';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Laburpena';
$lang['rss_content_o_diff']    = 'Bateratutako Diferentziak';
$lang['rss_content_o_htmldiff'] = 'HTML formatuko diferentzia taula';
$lang['rss_content_o_html']    = 'Orri edukia guztiz HTML';
$lang['rss_linkto_o_diff']     = 'Desberdintasunak ikusi';
$lang['rss_linkto_o_page']     = 'Berrikusitako orria';
$lang['rss_linkto_o_rev']      = 'Berrikuspen zerrenda';
$lang['rss_linkto_o_current']  = 'Uneko orria';
$lang['compression_o_0']       = 'ezer';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'ez erabili';
$lang['xsendfile_o_1']         = 'Jabegodun lighttpd goiburua (1.5 bertsioa baino lehen)';
$lang['xsendfile_o_2']         = 'X-Sendfile goiburu estandarra';
$lang['xsendfile_o_3']         = 'Jabegodun Nginx X-Accel-Redirect goiburua';
$lang['showuseras_o_loginname'] = 'Saio izena';
$lang['showuseras_o_username'] = 'Erabiltzailearen izen osoa';
$lang['showuseras_o_email']    = 'Erabiltzailearen posta-e helbidea (ezkutatua posta babeslearen aukeren arabera)';
$lang['showuseras_o_email_link'] = 'Erabiltzailearen posta-e helbidea mailto: esteka moduan';
$lang['useheading_o_0']        = 'Inoiz';
$lang['useheading_o_navigation'] = 'Nabigazioa Bakarrik';
$lang['useheading_o_content']  = 'Wiki Edukia Bakarrik';
$lang['useheading_o_1']        = 'Beti';

==> dokuwiki_0.0.20220731.a.orig.tar.gz: dokuwiki-2022-07-31a/lib/plugins/config/lang/eu/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Inko Illarramendi <inko.i.a@gmail.com>
 * @author Zigor Astarbe <astarbe@gmail.com>
 * @author Osoitz <oelkoro@gmail.com>
 */
$lang['menu']                  = 'Konfigurazio Ezarpenak';
$lang['error']                 = 'Ezarpenak ez dira eguneratu balio oker bat dela eta, mesedez errepasatu aldaketak eta berriz bidali. <br />Balio okerra(k) ertz gorriz inguratuak erakutsiko dira. ';
$lang['updated']               = 'Ezarpenak arrakastaz eguneratuak.';
$lang['nochoice']              = '(ez dago beste aukerarik)';
$lang['locked']                = 'Ezarpenen fitxategia ezin da eguneratu, eta intentzioa hau ez bada, <br />
ziurtatu ezarpen lokalen izena eta baimenak zuzenak direla.';
$lang['danger']                = 'Kontuz: Aukera hau aldatzeak zure wikia eta konfigurazio menua eskuraezin utzi dezake.';
$lang['warning']               = 'Oharra: Aukera hau aldatzeak ustekabeko portaera bat sortu dezake.';
$lang['security']              = 'Segurtasun Oharra: Aukera hau aldatzeak segurtasun arrisku bat sortu dezake.';
$lang['_configuration_manager'] = 'Konfigurazio Kudeatzailea';
$lang['_header_dokuwiki']      = 'DokuWiki Ezarpenak';
$lang['_header_plugin']        = 'Plugin Ezarpenak';
$lang['_header_template']      = 'Txantiloi Ezarpenak';
$lang['_header_undefined']     = 'Zehaztu gabeko Ezarpenak';
$lang['_basic']                = 'Oinarrizko Ezarpenak';
$lang['_display']              = 'Aurkezpen Ezarpenak';
$lang['_authentication']       = 'Kautotze Ezarpenak';
$lang['_anti_spam']            = 'Anti-Spam Ezarpenak';
$lang['_editing']              = 'Edizio Ezarpenak';
$lang['_links']                = 'Esteken Ezarpenak';
$lang['_media']                = 'Multimedia Ezarpenak';
$lang['_notifications']        = 'Abisuen ezarpenak';
$lang['_syndication']          = 'Sindikazio ezarpenak';
$lang['_advanced']             = 'Ezarpen Aurreratuak';
$lang['_network']              = 'Sare Ezarpenak';
$lang['_msg_setting_undefined'] = 'Ezarpen metadaturik ez.';
$lang['_msg_setting_no_class'] = 'Ezarpen klaserik ez.';
$lang['_msg_setting_no_default'] = 'Balio lehenetsirik ez.';
$lang['title']                 = 'Wiki-aren izenburua';
$lang['start']                 = 'Hasiera orriaren izena';
$lang['lang']                  = 'Hizkuntza';
$lang['template']              = 'Txantiloia';
$lang['license']               = 'Zein lizentziapean argitaratu beharko lirateke edukiak?';
$lang['savedir']               = 'Datuak gordetzeko direktorioa';
$lang['basedir']               = 'Oinarri direktorioa';
$lang['baseurl']               = 'Oinarri URLa';
$lang['dmode']                 = 'Direktorio sortze modua';
$lang['fmode']                 = 'Fitxategi sortze modua';
$lang['allowdebug']            = 'Baimendu debug-a <b>ezgaitu behar ez bada!</b>';
$lang['recent']                = 'Azken aldaketak';
$lang['recent_days']           = 'Zenbat azken aldaketa gordeko dira (egunak)';
$lang['breadcrumbs']           = 'Arrasto pauso kopurua';
$lang['youarehere']            = 'Arrasto pauso hierarkikoak';
$lang['fullpath']              = 'Orri oinean orrien bide osoa erakutsi';
$lang['typography']            = 'Ordezkapen tipografikoak egin';
$lang['dformat']               = 'Data formatua (ikusi PHPren <a href="http://php.net/strftime">strftime</a> funtzioa)';
$lang['signature']             = 'Sinadura';
$lang['showuseras']            = 'Zer azaldu orri bat editatu duen azken erabiltzailea erakusterakoan';
$lang['toptoclevel']           = 'Eduki taularen goiko maila';
$lang['tocminheads']           = 'Gutxiengo izenburu kopuru minimoa Edukien Taula-ren sortu dadin.';
$lang['maxtoclevel']           = 'Eduki taularen maila maximoa';
$lang['maxseclevel']           = 'Sekzio edizio mailaren maximoa';
$lang['camelcase']             = 'Estekentzat CamelCase erabili';
$lang['deaccent']              = 'Orri izen garbiak';
$lang['useheading']            = 'Erabili lehen izenburua orri izen moduan';
$lang['sneaky_index']          = 'Lehenespenez, DokuWiki-k izen-espazio guztiak indize bistan erakutsiko ditu. Aukera hau gaituta, erabiltzaieak irakurtzeko baimenik ez dituen izen-espazioak ezkutatuko dira. Honek atzigarriak diren azpi izen-espazioak ezkutatzen ditu. Agian honek indizea erabili ezin ahal izatea eragingo du AKL ezarpen batzuetan.';
$lang['hidepages']             = 'Ezkutatu kointzidentziak dituzten orriak (espresio erregularrak)';
$lang['useacl']                = 'Erabili atzipen kontrol listak';
$lang['autopasswd']            = 'Pasahitzak automatikoki sortu';
$lang['authtype']              = 'Kautotze backend-a';
$lang['passcrypt']             = 'Pasahitz enkriptatze metodoa';
$lang['defaultgroup']          = 'Talde lehenetsia';
$lang['superuser']             = 'Supererabiltzailea - taldea, erabiltzailea edo komaz bereiztutako zerrenda user1,@group1,user2 orri eta funtzio guztietara atzipen osoarekin, AKL-ren ezarpenetan zehaztutakoa kontutan hartu gabe';
$lang['manager']               = 'Kudeatzailea - talde, erabiltzaile edo komaz bereiztutako zerrenda user1,@group1,user2 kudeatze funtzio zehatz batzuetara atzipenarekin';
$lang['profileconfirm']        = 'Profil aldaketak pasahitzaz berretsi';
$lang['rememberme']            = 'Baimendu saio hasiera cookie iraunkorrak (gogoratu iezaidazu)';
$lang['disableactions']        = 'DokuWiki ekintzak ezgaitu';
$lang['disableactions_check']  = 'Egiaztatu';
$lang['disableactions_subscription'] = 'Harpidetu/Harpidetza utzi';
$lang['disableactions_wikicode'] = 'Ikusi iturburua/Esportatu Raw';
$lang['disableactions_other']  = 'Beste ekintzak (komaz bereiztuak)';
$lang['auth_security_timeout'] = 'Kautotze Segurtasun Denbora-Muga (segunduak)';
$lang['securecookie']          = 'HTTPS bidez ezarritako cookie-ak HTTPS bidez bakarrik bidali beharko lituzke nabigatzaileak? Ezgaitu aukera hau bakarrik saio hasierak SSL bidezko segurtasuna badu baina wiki-areb nabigazioa modu ez seguruan egiten bada. ';
$lang['usewordblock']          = 'Blokeatu spam-a hitz zerrenda batean oinarrituta';
$lang['relnofollow']           = 'Erabili rel="nofollow" kanpo esteketan';
$lang['indexdelay']            = 'Denbora atzerapena indexatu baino lehen (seg)';
$lang['mailguard']             = 'Ezkutatu posta-e helbidea';
$lang['iexssprotect']          = 'Egiaztatu igotako fitxategiak JavaScript edo HTML kode maltzurra detektatzeko';
$lang['usedraft']              = 'Automatikoki zirriborroa gorde editatze garaian';
$lang['htmlok']                = 'Enbotatutako HTMLa baimendu';
$lang['phpok']                 = 'Enbotatutako PHPa baimendu';
$lang['locktime']              = 'Adin maximoa lock fitxategientzat (seg)';
$lang['cachetime']             = 'Adin maximoa cachearentzat (seg)';
$lang['target____wiki']        = 'Barne estekentzat helburu leihoa';
$lang['target____interwiki']   = 'Interwiki estekentzat helburu leihoa';
$lang['target____extern']      = 'Kanpo estekentzat helburu leihoa';
$lang['target____media']       = 'Multimedia estekentzat helburu leihoa';
$lang['target____windows']     = 'Leihoen estekentzat helburu leihoa';
$lang['mediarevisions']        = 'Media rebisioak gaitu?';
$lang['refcheck']              = 'Multimedia erreferentzia kontrolatu';
$lang['gdlib']                 = 'GD Lib bertsioa';
$lang['im_convert']            = 'ImageMagick-en aldaketa tresnara bidea';
$lang['jpg_quality']           = 'JPG konprimitze kalitatea (0-100)';
$lang['fetchsize']             = 'Kanpo esteketatik fetch.php-k deskargatu dezakeen tamaina maximoa (byteak)';
$lang['subscribers']           = 'Gaitu orri harpidetza euskarria';
$lang['subscribe_time']        = 'Harpidetza zerrendak eta laburpenak bidali aurretik pasa beharreko denbora (seg); Denbora honek, recent_days-en ezarritakoa baino txikiagoa behar luke.';
$lang['notify']                = 'Aldaketen jakinarazpenak posta-e helbide honetara bidali';
$lang['registernotify']        = 'Erregistratu berri diren erabiltzaileei buruzko informazioa post-e helbide honetara bidali';
$lang['mailfrom']              = 'Posta automatikoentzat erabiliko den posta-e helbidea';
$lang['mailprefix']            = 'Posta automatikoen gaientzat erabili beharreko aurrizkia';
$lang['sitemap']               = 'Sortu Google gune-mapa (egunak)';
$lang['rss_type']              = 'XML jario mota';
$lang['rss_linkto']            = 'XML jarioak hona estekatzen du';
$lang['rss_content']           = 'Zer erakutsi XML jarioetan?';
$lang['rss_update']            = 'XML jarioaren eguneratze tartea (seg)';
$lang['rss_show_summary']      = 'XML jarioak laburpena erakusten du izenburuan';
$lang['updatecheck']           = 'Konprobatu eguneratze eta segurtasun oharrak? DokuWiki-k honetarako update.dokuwiki.org kontaktatu behar du.';
$lang['userewrite']            = 'Erabili URL politak';
$lang['useslash']              = 'Erabili barra (/) izen-espazio banatzaile moduan URLetan';
$lang['sepchar']               = 'Orri izenaren hitz banatzailea';
$lang['canonical']             = 'Erabili URL erabat kanonikoak';
$lang['fnencode']              = 'Non-ASCII fitxategi izenak kodetzeko metodoa.';
$lang['autoplural']            = 'Kontrolatu forma pluralak esteketan';
$lang['compression']           = 'Trinkotze metodoa attic fitxategientzat';
$lang['gzip_output']           = 'Gzip Eduki-Kodeketa erabili xhtml-rentzat';
$lang['compress']              = 'Trinkotu CSS eta javascript irteera';
$lang['send404']               = 'Bidali "HTTP 404/Ez Da Orria Aurkitu" existitzen ez diren orrientzat';
$lang['broken_iua']            = 'Zure sisteman ignore_user_abort (erabiltzailearen bertan behera uztea kontuan ez hartu) funtzioa hautsia al dago? Honek funtzionatzen ez duen bilaketa indize bat eragin dezake. ISS+PHP/CGI hautsiak daude. Ikusi <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> informazio gehiago jasotzeko.';
$lang['xsendfile']             = 'X-Sendfile goiburua erabili web zerbitzariari fitxategi estatikoak bidaltzen uzteko? Zure web zerbitzariak hau ahalbidetuta eduki beharko du.';
$lang['renderer_xhtml']        = 'Erabiliko den errenderizatzailea wiki irteera (xhtml) nagusiarentzat';
$lang['renderer__core']        = '%s (dokuwiki-ren nukleoa)';
$lang['renderer__plugin']      = '%s (plugina)';
$lang['proxy____host']         = 'Proxy zerbitzari izena';
$lang['proxy____port']         = 'Proxy portua';
$lang['proxy____user']         = 'Proxyaren erabiltzaile izena';
$lang['proxy____pass']         = 'Proxyaren pasahitza ';
$lang['proxy____ssl']          = 'Erabili SSL Proxyra konektatzeko';
$lang['proxy____except']       = 'URLak detektatzeko espresio erregularra, zeinentzat Proxy-a sahiestu beharko litzatekeen.';
$lang['license_o_']            = 'Bat ere ez hautaturik';
$lang['typography_o_0']        = 'ezer';
$lang['typography_o_1']        = 'Komatxo bikoitzak bakarrik';
$lang['typography_o_2']        = 'Komatxo guztiak (gerta daiteke beti ez funtzionatzea)';
$lang['userewrite_o_0']        = 'ezer';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'DokuWikiren barnekoa';
$lang['deaccent_o_0']          = 'Izalita';
$lang['deaccent_o_1']          = 'azentu-markak kendu';
$lang['deaccent_o_2']          = 'erromanizatu ';
$lang['gdlib_o_0']             = 'GD Lib ez dago eskuragarri';
$lang['gdlib_o_1']             = '1.x bertsioa';
$lang['gdlib_o_2']             = 'Automatikoki detektatu';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Laburpena';
$lang['rss_content_o_diff']    = 'Bateratutako Diferentziak';
$lang['rss_content_o_htmldiff'] = 'HTML formatuko diferentzia taula';
$lang['rss_content_o_html']    = 'Orri edukia guztiz HTML';
$lang['rss_linkto_o_diff']     = 'Desberdintasunak ikusi';
$lang['rss_linkto_o_page']     = 'Berrikusitako orria';
$lang['rss_linkto_o_rev']      = 'Berrikuspen zerrenda';
$lang['rss_linkto_o_current']  = 'Uneko orria';
$lang['compression_o_0']       = 'ezer';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'ez erabili';
$lang['xsendfile_o_1']         = 'Jabegodun lighttpd goiburua (1.5 bertsioa baino lehen)';
$lang['xsendfile_o_2']         = 'X-Sendfile goiburu estandarra';
$lang['xsendfile_o_3']         = 'Jabegodun Nginx X-Accel-Redirect goiburua';
$lang['showuseras_o_loginname'] = 'Saio izena';
$lang['showuseras_o_username'] = 'Erabiltzailearen izen osoa';
$lang['showuseras_o_email']    = 'Erabiltzailearen posta-e helbidea (ezkutatua posta babeslearen aukeren arabera)';
$lang['showuseras_o_email_link'] = 'Erabiltzailearen posta-e helbidea mailto: esteka moduan';
$lang['useheading_o_0']        = 'Inoiz';
$lang['useheading_o_navigation'] = 'Nabigazioa Bakarrik';
$lang['useheading_o_content']  = 'Wiki Edukia Bakarrik';
$lang['useheading_o_1']        = 'Beti';
$lang['readdircache']          = 'Aintzintasun maximoa readdir cache-rentzat (seg)';
